@@ -42,7 +42,7 @@ def update_msprofile(pt, row, dataset):
     spectrum = pt.cellWidget(row, 3).figure.get_axes()[0]
     spectrum.clear()
     limits = []
-    spectra = dataset.get_spectra(-np.inf, np.inf)
+    spectra = dataset.fullspectra
     for i, spectxy in enumerate(spectra):
         massargs = drl.get_subargs(pt, row, spectxy[0], 1, 2)
         spectrum.plot(spectxy[0], spectxy[1], ':', color='gray')
@@ -68,14 +68,15 @@ def update_mobprofile(pt, row, dataset):
     spectrum = pt.cellWidget(row, 6).figure.get_axes()[0]
     spectrum.clear()
     limits = []
-    spectra = dataset.get_mobspectra(-np.inf, np.inf)
-    for i, spectxy in enumerate(spectra):
-        massargs = drl.get_subargs(pt, row, spectxy[0], 4, 5)
-        spectrum.plot(spectxy[0], spectxy[1], ':', color='gray')
-        spectrum.plot(spectxy[0][massargs], spectxy[1][massargs],
-                      color=gt.colors[i % len(gt.colors)]/255)
-        limits.append((spectxy[0][massargs[[0, -1]]],
-                       max(spectxy[1][massargs])))
+    startm, endm = drl.get_range(drl.floatize(pt, row, 1),
+                                 drl.floatize(pt, row, 2))
+    spectxy = dataset.get_mobilogram(startm, endm)
+    massargs = drl.get_subargs(pt, row, spectxy[0], 4, 5)
+    spectrum.plot(spectxy[0], spectxy[1], ':', color='gray')
+    spectrum.plot(spectxy[0][massargs], spectxy[1][massargs],
+                  color=gt.colors[0]/255)
+    limits.append((spectxy[0][massargs[[0, -1]]],
+                   max(spectxy[1][massargs])))
     widest = np.argmax([abs(lim[0][1]-lim[0][0]) for lim in limits])
     xmin, xmax = limits[widest][0]
     xexlim = 0.02
@@ -93,7 +94,7 @@ def update_drlspectrum(ds, drls, drlspectrum):
     if not ds:
         return
 
-    names, times, intensities = drl.get_daughterset(ds, drls)
+    names, times, intensities = get_daughterset(ds, drls)
     drlspectrum.clear()
     gt.pop_plot([], [], drlspectrum, drls['graphlabels'])
     drlspectrum.axvline(0, 0, 0.9, color="#FF000088", linestyle=":")
@@ -130,10 +131,24 @@ def update_drlspectrum(ds, drls, drlspectrum):
         drlspectrum.legend(loc=2)
     drlspectrum.figure.canvas.draw()
 
+def gettableitemlist(ptable):
+    ion_list = []
+    for row in range(ptable.rowCount()):
+        text = []
+        for i in (0, 1, 2, 4, 5):
+            if not isinstance(ptable.item(row, i), type(None)):
+                frg = ptable.item(row, i).text()
+            else:
+                frg = ""
+            text.append(frg)
+        line = "{} ({}; fw={}, {}; fw={})".format(*text)
+        ion_list.append(line)
+    return ion_list
+
 
 def update_corrfors(drls):
     """update corrections selection layout of the daughter table"""
-    ionlist = drl.gettableitemlist(drls['pt'])
+    ionlist = gettableitemlist(drls['pt'])
     for row in range(drls['dt'].rowCount()):
         for i in range(drls['cors'].value()):
             corfor = drls['dt'].cellWidget(row, 1+i*2)
@@ -150,10 +165,12 @@ def ptable_changed(row, column, ds, drls, drlspectrum):
     """routine called by change of the ptable spectra"""
     logger.debug("ptable changed routine called")
     update_corrfors(drls)
-    drls['dt'].item(row, 0).setText(drl.gettableitemlist(drls['pt'])[row])
+    drls['dt'].item(row, 0).setText(gettableitemlist(drls['pt'])[row])
     if column in (1, 2):
         update_msprofile(drls['pt'], row, ds)
         update_mobprofile(drls['pt'], row, ds)
+    if column in (4, 5):
+        update_mobprofile(drls['pt'], row, ds)
 
 
 def dtable_changed(row, column, ds, drls, drlspectrum):
@@ -234,7 +251,7 @@ def remove_rows(ds, drls, drlspectrum, rows=None):
                 index = corfor.currentIndex()
                 corfor.clear()
                 corfor.addItem("")
-                corfor.addItems(drl.gettableitemlist(drls['pt']))
+                corfor.addItems(gettableitemlist(drls['pt']))
                 if index == row+1:
                     corfor.setCurrentIndex(0)
                     corr_changed(corfor, ds, drls, drlspectrum)
@@ -259,7 +276,7 @@ def add_line(ds, drls, drlspectrum):
         drls['pt'].setItem(newrow, i, QtWidgets.QTableWidgetItem())
         if newrow != 0:
             val = drl.floatize(drls['pt'], newrow-1, i)
-            if i != 2:
+            if i not in (2,4,5):
                 val = val+1
             drls['pt'].item(newrow, i).setText(str(val))
     for i in (3,6):
@@ -312,6 +329,8 @@ def load_drltables(parent, dataset, drls, drlspectrum):
     if filename != '':
         names = []
         masses = []
+        mobs = []
+        mob_widths=[]
         peak_widths = []
         states = []
         corrections = []
@@ -323,8 +342,8 @@ def load_drltables(parent, dataset, drls, drlspectrum):
         for i in range(1, len(rawdata)):
             rawline = rawdata[i].split(",")
             n = len(rawline)
-            if n < 4 or not n % 2 == 0 or (rawline[3] not in map(
-                str, range(3))) or not (set(map(int, rawline[4:n:2]))
+            if n < 6 or not n % 2 == 0 or (rawline[5] not in map(
+                str, range(3))) or not (set(map(int, rawline[6:n:2]))
                                         & set(range(-1, n)) or (n == 4)):
                 QtWidgets.QMessageBox.warning(
                     parent, "Load DRL config tables",
@@ -332,8 +351,8 @@ def load_drltables(parent, dataset, drls, drlspectrum):
                     "Error encountered on line {}.\n"
                     "Cancelling request.".format(i+1))
                 return
-            for j, k in enumerate((names, masses, peak_widths,
-                                   states, *corrections)):
+            for j, k in enumerate((names, masses, peak_widths, mobs,
+                                   mob_widths, states, *corrections)):
                 if len(rawline) > j:
                     k.append(rawline[j])
         for row in reversed(range(drls['pt'].rowCount())):
@@ -345,10 +364,12 @@ def load_drltables(parent, dataset, drls, drlspectrum):
             drls['pt'].item(i, 0).setText(names[i])
             drls['pt'].item(i, 1).setText(masses[i])
             drls['pt'].item(i, 2).setText(peak_widths[i])
+            drls['pt'].item(i, 4).setText(mobs[i])
+            drls['pt'].item(i, 5).setText(mob_widths[i])
         # and after that the daughter table
         drls['cors'].setValue(int((len(corrections) / 2)))
         for i in range(len(names)):
-            for j in range(int((len(rawline)-4)/2)):
+            for j in range(int((len(rawline)-6)/2)):
                 drls['dt'].cellWidget(i, 1+j*2).setCurrentIndex(
                     int(corrections[0+j*2][i]))
                 drls['dt'].item(i, 2+j*2).setText(corrections[1+j*2][i])
@@ -372,7 +393,7 @@ def save_drlconfig(drls, parent, exp_f_name=None):
                    "{}\n".format(cortext))
         for row in range(drls['pt'].rowCount()):
             vals = []
-            for i in range(3):
+            for i in (0,1,2,4,5):
                 vals.append(drls['pt'].item(row, i).text())
             vals.append(drls['dt'].cellWidget(row, 0).checkState())
             for i in range(drls['cors'].value()):
@@ -381,6 +402,63 @@ def save_drlconfig(drls, parent, exp_f_name=None):
             expf.write("{}\n".format((",".join(map(str, vals)))))
         expf.close()
 
+def get_intensity(row, ds, drls):
+    # prevent division by 0
+    startm, endm = drl.get_range(drl.floatize(drls['pt'], row, 1),
+                                 drl.floatize(drls['pt'], row, 2))
+    startmob, endmob = drl.get_range(drl.floatize(drls['pt'], row, 4),
+                                     drl.floatize(drls['pt'], row, 5))
+    intensity = ds.get_mzmobpeakchrom(startm, endm, startmob, endmob)
+    return intensity
+
+
+def get_daughterset(ds, drls):
+    """Fuction to acquire the curves of the daugher ions"""
+    logger.info("getting set of the daughter ions")
+    names = []
+    times = np.concatenate([sub[0] - drls['tshift'].value()
+                            for sub in ds.chromatograms])
+    intensities = []
+    for row in range(drls['dt'].rowCount()):
+        if drls['dt'].cellWidget(row, 0).checkState() == 2:
+            intensity = get_intensity(row, ds, drls)
+            corlist = []
+            for i in range(drls['cors'].value()):
+                cor = drls['dt'].cellWidget(row, 1+i*2).currentIndex() - 1
+                if cor not in (-2, -1):
+                    factor = drl.floatize(drls['dt'], row, 2+i*2, False)
+                    correction = get_intensity(cor, ds, drls) * factor
+                    intensity = intensity - correction
+                    corlist.append("{} * {}".format(
+                        drls['dt'].item(row, 2+i*2).text(),
+                        drls['dt'].cellWidget(row, 1+i*2).currentText()))
+            cortext = " + ".join(corlist)
+            intensities.append(intensity)
+            names.append("{} - ({})".format(
+                drls['dt'].item(row, 0).text(), cortext))
+    return names, times, intensities
+
+
+def get_parentset(ds, drls):
+    names = []
+    times = np.concatenate([sub[0] for sub in ds.chromatograms])
+    intensities = []
+    rowlist = []
+    for row in range(drls['dt'].rowCount()):
+        if drls['dt'].cellWidget(row, 0).checkState() == 2:
+            rowlist.append(row)
+            for corcol in range(drls['cors'].value()):
+                if drls['dt'].cellWidget(
+                        row, corcol*2 + 1).currentIndex() > 0\
+                        and drl.floatize(drls['dt'], row, 2) != 0:
+                    rowlist.append(
+                        drls['dt'].cellWidget(row, 1).currentIndex()-1)
+    for row in set(rowlist):
+        intensity = get_intensity(row, ds, drls)
+        intensities.append(intensity)
+        names.append(drls['dt'].item(row, 0).text())
+    return names, times, intensities
+
 
 def export_drlspectrum(parent, ds, drls):
     if not ds:
@@ -388,7 +466,7 @@ def export_drlspectrum(parent, ds, drls):
             None, "Export DRL dat aset",
             "No file opened. Nothing to export, canceling request")
         return
-    names, times, intensities = drl.get_daughterset(ds, drls)
+    names, times, intensities = get_daughterset(ds, drls)
     if drls['cutoff'].value() == 0:
         subset = np.where(times > 0)[0]
     else:
@@ -396,7 +474,7 @@ def export_drlspectrum(parent, ds, drls):
     times = times[subset]
     intensities = list(map(lambda x: x[subset], intensities))
 
-    pnames, ptimes, pintensities = drl.get_parentset(ds, drls)
+    pnames, ptimes, pintensities = get_parentset(ds, drls)
     if names == []:
         QtWidgets.QMessageBox.warning(
             None, "Export DRL data set",
