@@ -6,7 +6,6 @@ from PyQt5 import QtGui
 from PyQt5 import QtWidgets
 from PyQt5 import QtPrintSupport
 from prasopes.zcetools_help import helpstr
-from io import BytesIO
 import numpy as np
 import prasopes.graphtools as gt
 import prasopes.filetools as ft
@@ -129,7 +128,8 @@ def key_pressed(event, ds, coff, coffgrad):
     if event.key() == QtCore.Qt.Key_C:
         if event.modifiers().__int__() == QtCore.Qt.ControlModifier:
             painter = imgt.ImagePainter("zcespec")
-            painter.popfig = lambda: paint_override(painter, ds, coff, coffgrad)
+            painter.popfig = lambda: paint_override(
+                painter, ds, coff, coffgrad)
             painter.clip()
 
 
